==> ejc-zjkjcost-api-3.0.0-20220629.013418-19-sources.jar: com/ejianc/business/zjkjcost/node/vo/NodeGrantDetailVO.java <==
package com.ejianc.business.zjkjcost.node.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 节点考核-节点目标奖金考核发放-明细
 * 
 * @author generator
 * 
 */
@ApiModel("节点考核-节点目标奖金考核发放-明细")
public class NodeGrantDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("经办人")
    private Long detailEmployeeId;
    @ApiModelProperty("经办人名称")
    private String detailEmployeeName;
    @ApiModelProperty("经办部门")
    private Long detailDepartmentId;
    @ApiModelProperty("经办部门名称")
    private String detailDepartmentName;
    @ApiModelProperty("分配金额")
    private BigDecimal detailDistributionMny;
    @ApiModelProperty("实发金额")
    private BigDecimal detailActualMny;
    @ApiModelProperty("分配人签字")
    private String distributionSign;
    @ApiModelProperty("来源类型（0：新增，1：导入）")
    private Integer sourceType;
    @ApiModelProperty("来源类型名称")
    private String sourceTypeName;
    @ApiModelProperty("主表id")
    private Long grantId;
    @ApiModelProperty("来源id")
    private Long sourceId;
    @ApiModelProperty("来源名称")
    private String sourceName;
    

    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 经办人
     */
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    /**
     * 经办人
     */
    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    /**
     * 经办人名称
     */
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    /**
     * 经办人名称
     */
    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    /**
     * 经办部门
     */
    public Long getDetailDepartmentId() {
        return detailDepartmentId;
    }

    /**
     * 经办部门
     */
    public void setDetailDepartmentId(Long detailDepartmentId) {
        this.detailDepartmentId = detailDepartmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDetailDepartmentName() {
        return detailDepartmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDetailDepartmentName(String detailDepartmentName) {
        this.detailDepartmentName = detailDepartmentName;
    }
    /**
     * 分配金额
     */
    public BigDecimal getDetailDistributionMny() {
        return detailDistributionMny;
    }

    /**
     * 分配金额
     */
    public void setDetailDistributionMny(BigDecimal detailDistributionMny) {
        this.detailDistributionMny = detailDistributionMny;
    }
    /**
     * 实发金额
     */
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    /**
     * 实发金额
     */
    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    /**
     * 分配人签字
     */
    public String getDistributionSign() {
        return distributionSign;
    }

    /**
     * 分配人签字
     */
    public void setDistributionSign(String distributionSign) {
        this.distributionSign = distributionSign;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    /**
     * 来源类型名称
     */
    public String getSourceTypeName() {
        return sourceTypeName;
    }

    /**
     * 来源类型名称
     */
    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }
    /**
     * 主表id
     */
    public Long getGrantId() {
        return grantId;
    }

    /**
     * 主表id
     */
    public void setGrantId(Long grantId) {
        this.grantId = grantId;
    }
    /**
     * 来源id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源名称
     */
    public String getSourceName() {
        return sourceName;
    }

    /**
     * 来源名称
     */
    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }
    
}

==> ejc-zjkjcost-api-3.0.0-20250916.084832-234-sources.jar: com/ejianc/business/zjkjcost/node/vo/NodeGrantDetailVO.java <==
package com.ejianc.business.zjkjcost.node.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 节点考核-节点目标奖金考核发放-明细
 * 
 * @author generator
 * 
 */
@ApiModel("节点考核-节点目标奖金考核发放-明细")
public class NodeGrantDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("经办人")
    private Long detailEmployeeId;
    @ApiModelProperty("经办人名称")
    private String detailEmployeeName;
    @ApiModelProperty("经办部门")
    private Long detailDepartmentId;
    @ApiModelProperty("经办部门名称")
    private String detailDepartmentName;
    @ApiModelProperty("分配金额")
    private BigDecimal detailDistributionMny;
    @ApiModelProperty("实发金额")
    private BigDecimal detailActualMny;
    @ApiModelProperty("分配人签字")
    private String distributionSign;
    @ApiModelProperty("来源类型（0：新增，1：导入）")
    private Integer sourceType;
    @ApiModelProperty("来源类型名称")
    private String sourceTypeName;
    @ApiModelProperty("主表id")
    private Long grantId;
    @ApiModelProperty("来源id")
    private Long sourceId;
    @ApiModelProperty("来源名称")
    private String sourceName;


    private String errorMsg; // 导入错误信息


    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 经办人
     */
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    /**
     * 经办人
     */
    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    /**
     * 经办人名称
     */
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    /**
     * 经办人名称
     */
    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    /**
     * 经办部门
     */
    public Long getDetailDepartmentId() {
        return detailDepartmentId;
    }

    /**
     * 经办部门
     */
    public void setDetailDepartmentId(Long detailDepartmentId) {
        this.detailDepartmentId = detailDepartmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDetailDepartmentName() {
        return detailDepartmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDetailDepartmentName(String detailDepartmentName) {
        this.detailDepartmentName = detailDepartmentName;
    }
    /**
     * 分配金额
     */
    public BigDecimal getDetailDistributionMny() {
        return detailDistributionMny;
    }

    /**
     * 分配金额
     */
    public void setDetailDistributionMny(BigDecimal detailDistributionMny) {
        this.detailDistributionMny = detailDistributionMny;
    }
    /**
     * 实发金额
     */
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    /**
     * 实发金额
     */
    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    /**
     * 分配人签字
     */
    public String getDistributionSign() {
        return distributionSign;
    }

    /**
     * 分配人签字
     */
    public void setDistributionSign(String distributionSign) {
        this.distributionSign = distributionSign;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    /**
     * 来源类型名称
     */
    public String getSourceTypeName() {
        return sourceTypeName;
    }

    /**
     * 来源类型名称
     */
    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }
    /**
     * 主表id
     */
    public Long getGrantId() {
        return grantId;
    }

    /**
     * 主表id
     */
    public void setGrantId(Long grantId) {
        this.grantId = grantId;
    }
    /**
     * 来源id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源名称
     */
    public String getSourceName() {
        return sourceName;
    }

    /**
     * 来源名称
     */
    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }
    
}
